
/*  ___   ___  ___  _   _  ___   ___   ____ ___  ____  
 * / _ \ /___)/ _ \| | | |/ _ \ / _ \ / ___) _ \|    \ 
 *| |_| |___ | |_| | |_| | |_| | |_| ( (__| |_| | | | |
 * \___/(___/ \___/ \__  |\___/ \___(_)____)___/|_|_|_|
 *                  (____/ 
 * OSOYOO IoT Tutorial: Use OSOYOO IoT APP to  display remote temperature 
 * and humidity data collected from DHT11 sensor.
 * To run this code, you also need to install following libraries:
 * WifiEsp-master library, download link:https://osoyoo.com/driver/WiFiEsp-master.zip
 * PWMServo library, Download link:  https://osoyoo.com/driver/sg90car/PWMServo.zip 
 * Hardware: OSOYOO MEGA2560 board, MEGA IoT Wifi Shield , LED module
 * For more details see: https://osoyoo.com/?p=46283
 */


#include <WiFiEsp.h>
#include "OsoyooIOT.h"
#include <Wire.h> 
#include <LiquidCrystal_I2C.h>
#include<dht.h>
dht DHT;
LiquidCrystal_I2C lcd(0x27,16,2);  // set the LCD address to 0x27 for a 16 chars and 2 line display
#define DHT11_PIN 5

// Emulate softserial on pins 6/7 if not present

#include "SoftwareSerial.h"
SoftwareSerial softserial(A9, A8); // A9 to E_TX, A8 to E_RX


char ssid[] = "***";            // your network SSID (name)
char pass[] = "***";        // your network password
int status = WL_IDLE_STATUS;     // the Wifi radio's status

unsigned int localPort = 8888;  // local port to listen on

char packetBuffer[255];          // buffer to hold incoming packet
 
IPAddress phoneIP=IPAddress(192,168,1,255);//if your Arduino IP is sth like 192.168.0.xx set this value to 192.168.0.255
OsoyooIOT Udp;

void setup() {
  lcd.begin(16,2);
  lcd.init();                      // initialize the lcd 
  // Print a message to the LCD.
  lcd.backlight();
  lcd.clear();
  lcd.print("Humidity & temp");
  delay(1000);
  lcd.clear();
  lcd.print("Starting.....");
  delay(1000);
 
  
  Serial.begin(9600);   // initialize serial for debugging
  softserial.begin(115200);
  softserial.write("AT+CIOBAUD=9600\r\n");
  softserial.write("AT+RST\r\n");
  softserial.begin(9600);    // initialize serial for ESP module
  WiFi.init(&softserial);    // initialize ESP module

  // check for the presence of the shield:
  if (WiFi.status() == WL_NO_SHIELD) {
    Serial.println("WiFi shield not present");
    // don't continue:
    while (true);
  }

  // attempt to connect to WiFi network
  while ( status != WL_CONNECTED) {
    Serial.print("Attempting to connect to WPA SSID: ");
    Serial.println(ssid);
    // Connect to WPA/WPA2 network
    status = WiFi.begin(ssid, pass);
  }

  Serial.println("Connected to wifi");
  printWifiStatus();

  Serial.println("\nStarting connection to server...");
  // if you get a connection, report back via serial:
  Udp.begin(localPort);

  Serial.print("Listening on port ");
  Serial.println(localPort);
}
unsigned long oldTime=0;
unsigned long currentTime=0;
void loop() {
  currentTime = millis();
  
   
  
  int chk = DHT.read11(DHT11_PIN);
  lcd.clear();
  lcd.setCursor(0, 0);
  // print from 0 to 9:
  String tempstr="Temp: "+String(DHT.temperature,2)+" C";
  lcd.print(tempstr);
 
  String humidstr="Humid: "+String(DHT.humidity,2)+"%";
  // set the cursor to (16,1):
  lcd.setCursor(0,1);
  lcd.print(humidstr);

  String udpstr="Temp:"+String(DHT.temperature,2)+"C "+"Humid:"+String(DHT.humidity,2)+"%\n";
  int str_len = udpstr.length() + 1; 
  char udp_array[str_len];
  udpstr.toCharArray(udp_array, str_len);
  delay(100);
  Udp.loop();

 
  if (Udp.available()) {                               // if you get a client,
    Serial.print("Received packet of size ");
    Serial.println(Udp.packetSize());
    Serial.print("From ");
    phoneIP=Udp.remoteIP();
    Serial.print(phoneIP);
    OsoyooCommand myData = Udp.read();
    Serial.print(" Data Command:");
    String command = String(myData.command);
    Serial.println(command);
    Udp.beginPacket(phoneIP, 8888);
    Udp.write(udp_array,sizeof(udp_array)-1);
    Udp.endPacket();
  }
  if(currentTime>oldTime+2000){
    oldTime=currentTime;
    Udp.beginPacket(phoneIP, 8888);
    Udp.write(udp_array,sizeof(udp_array)-1);
    Udp.endPacket();
  }
}


void printWifiStatus() {
  // print the SSID of the network you're attached to:
  Serial.print("SSID: ");
  Serial.println(WiFi.SSID());

  // print your WiFi shield's IP address:
  IPAddress ip = WiFi.localIP();
  Serial.print("IP Address: ");
  Serial.println(ip);

  // print the received signal strength:
  long rssi = WiFi.RSSI();
  Serial.print("signal strength (RSSI):");
  Serial.print(rssi);
  Serial.println(" dBm");
}
